@@ -26,7 +26,7 @@ function tw_twd
 {
 	if [[ -f "$1" ]]
 	then
-		TW_TERM=$(printf "$2" | sed -e 's,(,\\(,g' -e 's,),\\),g')
+		TW_TERM=$(sed -e 's,(,\\(,g' -e 's,),\\),g' <<< "$2")
 		gawk -F" : " '$1 ~ /'"$TW_TERM"'/' "$1"
 		exit 0
 	else
@@ -59,7 +59,7 @@ function tw_freetranslation
 #		en-zh) TW_LANGUAGE="English/SimplifiedChinese";;
 #		en-zt) TW_LANGUAGE="English/TraditionalChinese";;
 	esac
-	TW_TERM=$(printf "$2" | iconv -f "UTF-8" -t "ISO-8859-15")
+	TW_TERM=$(iconv -f "UTF-8" -t "ISO-8859-15" <<< "$2")
 	curl -s -d "srctext=${TW_TERM}" -d "language=${TW_LANGUAGE}" \
 	-d "sequence=core" http://ets.freetranslation.com | \
 	iconv -f "ISO-8859-15" -t "UTF-8"
